@@ -1,7 +1,7 @@
 #ifndef __GDICT_APP_H_
 #define __GDICT_APP_H_
 
-/* $Id: gdict-app.h,v 1.8 2000/05/19 00:18:59 hovinen Exp $ */
+/* $Id: gdict-app.h,v 1.11 2001/12/05 22:38:30 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -21,8 +21,8 @@
 #  include <libgnomeprint/gnome-print.h>
 #endif /* HAVE_GNOME_PRINT */
 
-#include "gdict-defbox.h"
 #include "gdict-speller.h"
+#include "gdict-defbox.h"
 #include "gdict-pref-dialog.h"
 
 extern GtkWidget *gdict_app;
@@ -32,6 +32,7 @@ extern GDictDefbox *defbox;
 extern GDictSpeller *speller;
 extern GtkWidget *pref_dialog;
 
+
 #ifdef HAVE_GNOME_PRINT
 extern GnomePrinter *gdict_printer;
 #endif /* HAVE_GNOME_PRINT */
@@ -45,6 +46,6 @@ void gdict_app_clear (void);
 void gdict_app_do_lookup (gchar *text);
 void gdict_app_show_preferences (void);
 void gdict_not_online (void);
-GtkWidget *gdict_app_create (void);
+GtkWidget *gdict_app_create (gboolean applet);
 
 #endif /* __GDICT_APP_H_ */
